from enum import Enum

SECURITY_CONTEXT_URL = 'https://w3id.org/security/v1'
OPEN_BADGES_V2_CONTEXT = 'https://openbadgespec.org/v2/context.json'
BLOCKCERTS_V2_CONTEXT = 'https://www.blockcerts.org/blockcerts_v2_alpha/context_bc.json'
BLOCKCERTS_V2_SCHEMA = 'https://www.blockcerts.org/blockcerts_v2_alpha/obi/schema.json'
PUBKEY_PREFIX = 'ecdsa-koblitz-pubkey:'
BLOCKCERTS_VOCAB = 'https://www.blockcerts.org/blockcerts_v2_alpha/vocab/blockcerts#'
BLOCKCERTS_PREFIX = 'bc:'


class Error(Exception):
    """Base class for exceptions in this module"""
    pass


class UnknownChainError(Error):
    """
    Didn't recognize chain
    """
    pass


class UnknownBlockcertVersionException(Error):
    """
    Didn't recognize blockcert version
    """
    pass


class Chain(Enum):
    mainnet = 0, 'BTC'
    testnet = 1, 'XTN'
    regtest = 2, 'XTN'

    def __new__(cls, enum_value, netcode):
        obj = object.__new__(cls)
        obj._value_ = enum_value
        obj.netcode = netcode
        return obj

    @staticmethod
    def parse_from_chain(chain_string):
        if chain_string == 'mainnet':
            return Chain.mainnet
        elif chain_string == 'testnet':
            return Chain.testnet
        elif chain_string == 'regtest':
            return Chain.regtest
        else:
            raise UnknownChainError(chain_string)

    @staticmethod
    def parse_from_netcode(netcode_string):
        if netcode_string == 'BTC':
            return Chain.mainnet
        elif netcode_string == 'XTN':
            return Chain.testnet
        else:
            raise UnknownChainError(netcode_string)


def parse_chain_from_address(address):
    if address.startswith('1'):
        return Chain.mainnet
    elif address.startswith('m') or address.startswith('n'):
        return Chain.testnet
    else:
        raise UnknownChainError('Unrecognized bitcoin address')


class BlockcertVersion(Enum):
    V1_1 = 0
    V1_2 = 1
    V2 = 2


